About
=====

Euphorie is a tool for risk assessment.  It was developed by `SYSLAB`_ and `TNO`_
in cooperation with `Simplon B.V.`_ and `Cornelis Kolbach`_ in commission of
`The European Agency for Safety and Health at Work`_ as part of the
`Healthy Workplaces`_ campaign.
   
.. _syslab: http://syslab.com/
.. _TNO: http://www.tno.nl/index.cfm?Taal=2
.. _Simplon B.V.: http://www.simplon.biz/
.. _Cornelis Kolbach: http://cornae.org/
.. _The European Agency for Safety and Health at Work: http://osha.europa.eu/en/
.. _Healthy Workplaces: http://osha.europa.eu/en/campaigns/hw2008


Introduction
============

The Euphorie risk assessment tool is based on hierarchical questionnaires. A
questionnaire (or survey) covers all possible risks for a specific sector of
industry.

Each sector organisation can have one or more surveys published simultaneously.
In order to facilitate development and testing of surveys the system supports
multiple versions for a survey. Only a single version of a survey can be public
at any point in time.

More information
================

For more information please see the `online documentation
<http://euphorie.readthedocs.org>`_.

